import click
import os
from curldrop.app import app
from curldrop.server import StandaloneServer


@click.command()
@click.option("--port", default=8000, help="Port to listen on, default is 8000")
@click.option(
    "--upload-dir",
    default=os.getcwd(),
    help="Directory where uploads are stored, if not specified the current working directory will be used",
)
@click.option("--baseurl", default=None, help="Base URL, e.g. http://example.com:8000/")
@click.option(
    "--timeout", default=30, help="Number of seconds before a worker will timeout"
)
@click.option("--workers", default=4, help="Number of workers")
def main(port, upload_dir, baseurl, timeout, workers):
    if not baseurl:
        baseurl = "http://{host}:{port}/".format(host="localhost", port=port)
        click.echo(
            click.style(
                "You did not specify a Base URL, using default: " + baseurl, fg="yellow"
            )
        )

    app.config["UPLOAD_DIR"] = upload_dir
    app.config["BASE_URL"] = baseurl

    server_options = {
        "bind": "{ip}:{port}".format(ip="0.0.0.0", port=port),
        "workers": workers,
        "accesslog": "-",
        "errorlog": "-",
        "timeout": timeout,
    }
    StandaloneServer(app, server_options).run()


if __name__ == "__main__":
    main()



from gunicorn.app.base import BaseApplication
from six import iteritems


class StandaloneServer(BaseApplication):
    def __init__(self, app, options=None):
        self.options = options or {}
        self.application = app
        super(StandaloneServer, self).__init__()

    def load_config(self):
        config = dict(
            [
                (key, value)
                for key, value in iteritems(self.options)
                if key in self.cfg.settings and value is not None
            ]
        )
        for key, value in iteritems(config):
            self.cfg.set(key.lower(), value)

    def load(self):
        return self.application



import os
from flask import Flask, abort, request, send_file
from werkzeug.utils import secure_filename
from uuid import uuid4


app = Flask(__name__)


@app.route("/")
def index():
    return (
        '<a href="https://github.com/kennell/curldrop">curldrop</a> is up and running'
    )


@app.route("/<file>", methods=["PUT"])
def upload(file):
    uuid = uuid4().hex[:8]
    filename = uuid + "-" + secure_filename(file)
    savepath = os.path.join(app.config["UPLOAD_DIR"], filename)
    with open(savepath, "wb") as f:
        f.write(request.data)
    return app.config["BASE_URL"] + uuid


@app.route("/<uuid>", methods=["GET"])
def download(uuid):
    for file in os.listdir(app.config["UPLOAD_DIR"]):
        if file.startswith(uuid):
            return send_file(
                os.path.join(os.getcwd(), app.config["UPLOAD_DIR"], file),
                as_attachment=True,
                attachment_filename=file.split("-", 1)[1],
            )
    return abort(404)



from setuptools import setup, find_packages

setup(
    name="curldrop",
    version="1.0.5",
    packages=find_packages(),
    author="Kevin Kennell",
    author_email="kevin@kennell.de",
    license="MIT",
    url="http://github.com/kennell/curldrop",
    install_requires=["flask", "click", "gunicorn", "six"],
    entry_points={"console_scripts": ["curldrop = curldrop.cli:main"]},
)
